
#ifndef NOERROR2
#error "NOERROR2 was not passed"
#endif

#ifndef NOERROR4
#error "NOERROR4 was not passed"
#endif

#ifndef NOERROR5
#error "NOERROR5 was not passed"
#endif

#ifndef NOERROR6
#error "NOERROR6 was not passed"
#endif

int foo(int x) {
    return x + 42;
}
